@@ -53,6 +53,9 @@ class EventHandler:
             "GUILD_ROLE_CREATE": GuildRoleCreate,
             "GUILD_ROLE_UPDATE": GuildRoleUpdate,
             "GUILD_ROLE_DELETE": GuildRoleDelete,
+            "GUILD_SCHEDULED_EVENT_CREATE": GuildScheduledEventCreate,
+            "GUILD_SCHEDULED_EVENT_UPDATE": GuildScheduledEventUpdate,
+            "GUILD_SCHEDULED_EVENT_DELETE": GuildScheduledEventDelete,
             "INTEGRATION_CREATE": IntegrationCreate,
             "INTEGRATION_UPDATE": IntegrationUpdate,
             "INTEGRATION_DELETE": IntegrationDelete,
